@@ -25,7 +25,8 @@ class EmsCliCompare:
             )
         )
         logger.debug(
-            "Projects in the current instance: %s", self.ems_service.projects,  # type: ignore
+            "Projects in the current instance: %s",
+            self.ems_service.projects,  # type: ignore
         )
         error_counter = 0
         error_log = []
@@ -77,9 +78,8 @@ class EmsCliCompare:
         logger.info("Starting Compare")
         if variant_master_found1:
             logger.info(
-                "An objectclass of type 'VNTMASTER' was found in {}. Switching to variant mode!".format(
-                    project1
-                )
+                "An objectclass of type 'VNTMASTER' was found in {}. Switching to"
+                " variant mode!".format(project1)
             )
             if variant_master_found2:
                 logger.info(
@@ -164,20 +164,24 @@ class EmsCliCompare:
                                 # features1 = list(layer_data1.resolve())
                                 # features2 = list(layer_data2.resolve())
                                 if layer_data1.length != layer_data2.length:
-                                    error_message = "Feature list count of {}/{}/{}/{} is NOT equal ({} != {})!".format(
-                                        project1,
-                                        variant1["NAME"],
-                                        objectclass.name,
-                                        layer.name,
-                                        layer_data1.length,
-                                        layer_data2.length,
+                                    error_message = (
+                                        "Feature list count of {}/{}/{}/{} is NOT equal"
+                                        " ({} != {})!".format(
+                                            project1,
+                                            variant1["NAME"],
+                                            objectclass.name,
+                                            layer.name,
+                                            layer_data1.length,
+                                            layer_data2.length,
+                                        )
                                     )
                                     logger.error(error_message)
                                     error_log.append(error_message)
                                     error_counter += 1
                                     if error_counter >= 100:
                                         logger.error(
-                                            "Too many differences: stopping the compare."
+                                            "Too many differences: stopping the"
+                                            " compare."
                                         )
                                         break
 
@@ -193,12 +197,15 @@ class EmsCliCompare:
                         project2.objectclass(objectclass.name).layer(layer.name).query()
                     )
                     if layer_data1.length != layer_data2.length:
-                        error_message = "Feature list count of {}/{}/{} is NOT equal ({} != {})!".format(
-                            project1,
-                            objectclass.name,
-                            layer.name,
-                            layer_data1.length,
-                            layer_data2.length,
+                        error_message = (
+                            "Feature list count of {}/{}/{} is NOT equal ({} != {})!"
+                            .format(
+                                project1,
+                                objectclass.name,
+                                layer.name,
+                                layer_data1.length,
+                                layer_data2.length,
+                            )
                         )
                         logger.error(error_message)
                         error_log.append(error_message)
