@@ -35,7 +35,7 @@ logger = logging.getLogger("ems_cli_export")
 try:
     from osgeo import gdal
 except ImportError:
-    logger.error("This function need GDAL Python bindings.")
+    logger.error("This function needs GDAL Python bindings.")
     raise ImportError("No GDAL Provided")
 
 
