@@ -1,17 +1,33 @@
-﻿# -*- coding: utf-8 -*-
+﻿#
+# The MIT License (MIT)
+# Copyright (c) 2022 M.O.S.S. Computer Grafik Systeme GmbH
+#
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the "Software"),
+# to deal in the Software without restriction, including without limitation
+# the rights to use, copy, modify, merge, publish, distribute, sublicense,
+# and/or sell copies of the Software, and to permit persons to whom the Software
+# is furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included
+# in all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT,TORT OR OTHERWISE, ARISING FROM, OUT
+# OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
-# Copyright (c) 2020  by M.O.S.S. Computer Grafik Systeme GmbH
-#                         Hohenbrunner Weg 13
-#                         D-82024 Taufkirchen
-#                         http://www.moss.de#
 
-from moss.ems.utilities.pagination_query import EmsPaginationQueryException
-from moss.ems import emslayer
+import logging
 import os
 from os.path import join
-import logging
+
 from tqdm import tqdm
 
+from moss.ems.utilities.pagination_query import EmsPaginationQueryException
+
 logger = logging.getLogger("ems_cli_export")
 
 
